==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.js" line="+77"/>
        <source>Position</source>
        <translation>Poloha</translation>
    </message>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Natočenie:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>Natočiť vkladané prvky&lt;br&gt;pod týmto uhlom</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale:</source>
        <translation>Mierka:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>Mierka vkladaných prvkov&lt;br&gt;podľa tohto Faktora</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>Zrkadliť vodorovne&lt;br&gt;vkladané prvky</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>Zrkadliť zvisle&lt;br&gt;vkladané prvky</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation>Prilepiť všetky prvky&lt;br&gt;z pôvodnej vrstvy&lt;br&gt;na aktuálnu vrstvu</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translation>Na aktuálnu vrstvu</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>Prepísať existujúce vrstvy&lt;br&gt;vo výkrese vrstvami&lt;br&gt;zo schránky</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>Prepísať vrstvy</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>Prepísať existujúce bloky&lt;br&gt;vo výkrese blokmi&lt;br&gt;zo schránky</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>Prepísať bloky</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translation>&amp;Prilepiť</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.js" line="+52"/>
        <source>Edit</source>
        <translation>Upraviť</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paste</source>
        <translation>Vložiť</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Position</source>
        <translation>Poloha</translation>
    </message>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Natočenie:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>Natočiť vkladané prvky&lt;br&gt;pod týmto uhlom</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scale:</source>
        <translation>Mierka:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>Mierka vkladaných prvkov&lt;br&gt;podľa tohto Faktora</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>Zrkadliť vodorovne&lt;br&gt;vkladané prvky</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>Zrkadliť zvisle&lt;br&gt;vkladané prvky</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation>Prilepiť všetky prvky&lt;br&gt;z pôvodnej vrstvy&lt;br&gt;na aktuálnu vrstvu</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translation>Na aktuálnu vrstvu</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>Prepísať existujúce vrstvy&lt;br&gt;vo výkrese vrstvami&lt;br&gt;zo schránky</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>Prepísať vrstvy</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>Prepísať existujúce bloky&lt;br&gt;vo výkrese blokmi&lt;br&gt;zo schránky</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>Prepísať bloky</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translation>&amp;Prilepiť</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Reset to defaults every time tool is used</source>
        <translation>Obnoviť pôvodné nastavenia pri každom použití nástroja</translation>
    </message>
</context>
</TS>
